@@ -40,21 +40,11 @@ filter..tidytable <- function(.df, ..., .by = NULL) {
 
   i <- call_reduce(dots, "&")
 
-  if (quo_is_null(.by)) {
-    dt_expr <- call2_i(.df, i)
+  .by <- tidyselect_names(.df, !!.by)
 
-    .df <- eval_tidy(dt_expr, data = .df, env = dt_env)
-  } else {
-    .by <- tidyselect_names(.df, !!.by)
+  dt_expr <- call2_i(.df, i, .by)
 
-    j <- expr(.I[!!i])
-
-    dt_expr <- call2_fast_by_i(.df, j, .by)
-
-    .df <- eval_tidy(dt_expr, data = .df, env = dt_env)
-  }
-
-  .df
+  eval_tidy(dt_expr, .df, dt_env)
 }
 
 #' @export
