@@ -23,7 +23,7 @@ uncount..tidytable <- function(.df, weights, .remove = TRUE, .id = NULL) {
 
   .reps <- pull.(.df, !!weights)
 
-  result_df <- dt(.df, vec_rep_each(1:.N, .reps))
+  result_df <- vec_rep_each(.df, .reps)
 
   if (!is.null(.id)) {
     result_df <- dt_j(result_df, !!.id := sequence(.reps))
