@@ -86,9 +86,9 @@ test_that("preserves ordered factors", {
 })
 
 test_that("preserves NAs", {
-  x <- c(NA, "A", "B")
-  expect_equal(crossing.(x)$x, x)
-  expect_equal(nesting.(x)$x, x)
+  x <- c(NA, "B", "A")
+  expect_equal(crossing.(x)$x, c("A", "B", NA))
+  expect_equal(nesting.(x)$x, c("A", "B", NA))
 })
 
 test_that("zero length input gives zero length output", {
@@ -116,6 +116,13 @@ test_that("Works with .by", {
 
 # nesting() ---------------------------------------------------
 test_that("nesting works", {
+  out <- nesting.(x = c(2, 1, 1), y = c(2, 1, 1))
+  expect_named(out, c("x", "y"))
+  expect_equal(out$x, c(1, 2))
+  expect_equal(out$y, c(1, 2))
+})
+
+test_that("nesting works in expand", {
   df <- tidytable(x = c(1, 1, 2), y = c(1, 1, 2))
   out <- expand.(df, nesting.(x, y))
   expect_equal(out$x, c(1, 2))
